==> basic-data-api-1.0.10.tgz: package/src/RequestSettings/floor.js <==
import {
  submit,
  batchDeletion,
  pagingQuery,
  singleQueryPath,
  postQueryData,
} from "../publicMethod/PublicMethod.js";
import floorApi from "../api/floorApi";
import { request } from "../globalConfiguration";
//楼层接口
const PagesData = {
  floorNumber: undefined,
  floorName: undefined,
  campusId: undefined,
  teachingBuildingId: undefined,
  orgId: undefined,
  flooMark: undefined,
};
/**
 * @Post 请求
 *添加楼层
 * @param {data} 参数
 * {floorNumber} 楼层编号  *
 * {floorName} 楼层名称  *
 * {campusId} 校区id  *
 * {teachingBuildingId} 教学楼id *
 * {orgId} 机构id *
 * {flooMark} 楼层号
 * @param {config} 配置项
 * @returns
 */
function addFloor(data = PagesData, config = {}) {
  return request(
    submit(
      {
        lcbh: data.floorNumber || undefined, //楼层编号
        lcmc: data.floorName || undefined, //楼层名称
        fkXqId: data.campusId || undefined, // 校区id
        fkJxlId: data.teachingBuildingId || undefined, // 教学楼id
        fkJgId: data.orgId || undefined, // 机构id
        lcno: data.flooMark || undefined, //  楼层号
      },
      floorApi.addFloor,
      config
    )
  );
}

/**
 * @Post 请求
 *更新楼层
 * @param {data} 参数
 * {id}  楼层id
 * {floorNumber} 楼层编号  *
 * {floorName} 楼层名称  *
 * {campusId} 校区id  *
 * {teachingBuildingId} 教学楼id *
 * {orgId} 机构id *
 * {flooMark} 楼层号
 * @param {config} 配置项
 * @returns
 */
function updateFloor(
  data = {
    id: undefined,
    ...PagesData,
  },
  config = {}
) {
  return request(
    submit(
      {
        id: data.id || undefined, //楼层id
        lcbh: data.floorNumber || undefined, //楼层编号
        lcmc: data.floorName || undefined, //楼层名称
        fkXqId: data.campusId || undefined, // 校区id
        fkJxlId: data.teachingBuildingId || undefined, // 教学楼id
        fkJgId: data.orgId || undefined, // 机构id
        lcno: data.flooMark || undefined, //  楼层号
      },
      floorApi.updateFloor,
      config
    )
  );
}

/**
 * @Delete 请求
 *批量删除楼层
 * @param {data} 参数 传入要删除的数组 []
 * @param {config} 配置项
 * @returns
 */
function delBatchFloor(data, config = {}) {
  return request(batchDeletion(data, floorApi.delBatchFloor, config));
}

/**
 * @Get 请求
 *根据id查询楼层
 * @param {data} 参数 传入要查询的id
 * @param {config} 配置项
 * @returns
 */
function getFloorById(data, config = {}) {
  return new Promise((resolve, reject) => {
    request(singleQueryPath(data, floorApi.getFloorById, config))
      .then(({ result }) => {
        resolve({
          id: result.id || undefined,
          floorNumber: result.lcbh || undefined,
          floorName: result.lcmc || undefined,
          flooMark: result.lcno || undefined,
          campusId: result.fkXqId || undefined, // 校区id
          campusName: result.xqmc || undefined, // 校区名称
          teachingBuildingId: result.fkJxlId || undefined, // 教学楼id
          teachingBuildingName: result.jxlmc || undefined, // 教学楼名称
          orgId: item.fkJgId || undefined, // 机构id
          orgName: item.jgmc || undefined, // 机构名称
        });
      })
      .catch(() => {
        reject({});
      });
  });
}

/**
 * @Post 请求
 *查询楼层列表
 * @param {data} 参数
 * {floorNumber} 楼层编号
 * {floorName} 名称
 * {campusId} 校区id
 * {teachingBuildingId} 教学楼id
 * {orgId} 机构id
 * @param {config} 配置项
 * @returns
 */
function queryFloorList(data = PagesData, config = {}) {
  return new Promise((resolve, reject) => {
    request(
      postQueryData(
        {
          lcbh: data.floorNumber || undefined, //楼层编号
          lcmc: data.floorName || undefined, //楼层名称
          fkJgId: data.orgId || undefined, // 机构id
          fkXqId: result.campusId || undefined, // 校区id
          fkJxlId: result.teachingBuildingId || undefined, // 教学楼id
        },
        floorApi.queryFloorList,
        config
      )
    ).then(({ result }) => {
      resolve(
        result.map((item) => ({
          value: item.id || undefined,
          label: item.lcmc || undefined,
          flooMark: result.lcno || undefined,
          orgId: item.fkJgId || undefined,
          orgName: item.jgmc || undefined,
          floorNumber: result.lcbh || undefined,
          campusId: result.fkXqId || undefined,
          campusName: result.xqmc || undefined,
          teachingBuildingId: result.fkJxlId || undefined,
          teachingBuildingName: result.jxlmc || undefined,
        }))
      );
    });
  });
}

/**
 * @Post 请求
 *分页查询
 * @param {data} 参数
 * {floorName} 楼层名称
 * {orgId}  机构id
 * {campusIds} 校区ids 数组
 * 除上面两个参数外 其他参数可自定义
 * @param {config} 配置项
 * @returns
 */
function listPagesFloor(data = PagesData, config = {}) {
  return new Promise((resolve, reject) => {
    request(
      pagingQuery(
        {
          lcmc: data.floorName || undefined, //楼层名称
          orgId: data.orgId || undefined, //机构id
          xqIds:data.campusIds || undefined, //校区ids 数组
          ...data,
          ...PagesData,
        },
        floorApi.listPagesFloor,
        config
      )
    )
      .then(({ result }) => {
        const { list, pageInfo } = result;
        resolve({
          list:
            list.length > 0
              ? list.map((item) => ({
                  id: item.id || undefined,
                  floorNumber: item.lcbh || undefined,
                  floorName: item.lcmc || undefined,
                  flooMark: result.lcno || undefined,
                  orgId: item.fkJgId || undefined,
                  orgName: item.jgmc || undefined,
                  floorNumber: result.lcbh || undefined,
                  campusId: result.fkXqId || undefined,
                  campusName: result.xqmc || undefined,
                  teachingBuildingId: result.fkJxlId || undefined,
                  teachingBuildingName: result.jxlmc || undefined,
                }))
              : [],
          pageInfo: pageInfo,
        });
      })
      .catch((err) => {
        reject(err);
      });
  });
}

export {
  addFloor,
  updateFloor,
  delBatchFloor,
  getFloorById,
  queryFloorList,
  listPagesFloor,
};

==> basic-data-api-1.0.14.tgz: package/src/RequestSettings/floor.js <==
import {
  submit,
  batchDeletion,
  pagingQuery,
  singleQueryPath,
  postQueryData,
} from "../publicMethod/PublicMethod.js";
import floorApi from "../api/floorApi";
import { request } from "../globalConfiguration";
//楼层接口
const PagesData = {
  floorNumber: undefined,
  floorName: undefined,
  campusId: undefined,
  teachingBuildingId: undefined,
  teachingBuildingName:undefined,
  campusIds:undefined,
  orgId: undefined,
  flooMark: undefined,
};
/**
 * @Post 请求
 *添加楼层
 * @param {data} 参数
 * {floorNumber} 楼层编号  *
 * {floorName} 楼层名称  *
 * {campusId} 校区id  *
 * {teachingBuildingId} 教学楼id *
 * {orgId} 机构id *
 * {flooMark} 楼层号
 * @param {config} 配置项
 * @returns
 */
function addFloor(data = PagesData, config = {}) {
  return request(
    submit(
      {
        lcbh: data.floorNumber || undefined, //楼层编号
        lcmc: data.floorName || undefined, //楼层名称
        fkXqId: data.campusId || undefined, // 校区id
        fkJxlId: data.teachingBuildingId || undefined, // 教学楼id
        fkJgId: data.orgId || undefined, // 机构id
        lcno: data.flooMark || undefined, //  楼层号
      },
      floorApi.addFloor,
      config
    )
  );
}

/**
 * @Post 请求
 *更新楼层
 * @param {data} 参数
 * {id}  楼层id
 * {floorNumber} 楼层编号  *
 * {floorName} 楼层名称  *
 * {campusId} 校区id  *
 * {teachingBuildingId} 教学楼id *
 * {orgId} 机构id *
 * {flooMark} 楼层号
 * @param {config} 配置项
 * @returns
 */
function updateFloor(
  data = {
    id: undefined,
    ...PagesData,
  },
  config = {}
) {
  return request(
    submit(
      {
        id: data.id || undefined, //楼层id
        lcbh: data.floorNumber || undefined, //楼层编号
        lcmc: data.floorName || undefined, //楼层名称
        fkXqId: data.campusId || undefined, // 校区id
        fkJxlId: data.teachingBuildingId || undefined, // 教学楼id
        fkJgId: data.orgId || undefined, // 机构id
        lcno: data.flooMark || undefined, //  楼层号
      },
      floorApi.updateFloor,
      config
    )
  );
}

/**
 * @Delete 请求
 *批量删除楼层
 * @param {data} 参数 传入要删除的数组 []
 * @param {config} 配置项
 * @returns
 */
function delBatchFloor(data, config = {}) {
  return request(batchDeletion(data, floorApi.delBatchFloor, config));
}

/**
 * @Get 请求
 *根据id查询楼层
 * @param {data} 参数 传入要查询的id
 * @param {config} 配置项
 * @returns
 */
function getFloorById(data, config = {}) {
  return new Promise((resolve, reject) => {
    request(singleQueryPath(data, floorApi.getFloorById, config))
      .then(({ result }) => {
        resolve({
          id: result.id || undefined,
          floorNumber: result.lcbh || undefined,
          floorName: result.lcmc || undefined,
          flooMark: result.lcno || undefined,
          campusId: result.fkXqId || undefined, // 校区id
          campusName: result.xqmc || undefined, // 校区名称
          teachingBuildingId: result.fkJxlId || undefined, // 教学楼id
          teachingBuildingName: result.jxlmc || undefined, // 教学楼名称
          orgId: result.fkJgId || undefined, // 机构id
          orgName: result.jgmc || undefined, // 机构名称
        });
      })
      .catch(() => {
        reject({});
      });
  });
}

/**
 * @Post 请求
 *查询楼层列表
 * @param {data} 参数
 * {floorNumber} 楼层编号
 * {floorName} 名称
 * {campusId} 校区id
 * {teachingBuildingId} 教学楼id
 * {orgId} 机构id
 * @param {config} 配置项
 * @returns
 */
function queryFloorList(data = PagesData, config = {}) {
  return new Promise((resolve, reject) => {
    request(
      postQueryData(
        {
          lcbh: data.floorNumber || undefined, //楼层编号
          lcmc: data.floorName || undefined, //楼层名称
          fkJgId: data.orgId || undefined, // 机构id
          fkXqId: data.campusId || undefined, // 校区id
          fkJxlId: data.teachingBuildingId || undefined, // 教学楼id
        },
        floorApi.queryFloorList,
        config
      )
    ).then(({ result }) => {
      resolve(
        result.map((item) => ({
          value: item.id || undefined,
          label: item.lcmc || undefined,
          flooMark: result.lcno || undefined,
          orgId: item.fkJgId || undefined,
          orgName: item.jgmc || undefined,
          floorNumber: item.lcbh || undefined,
          campusId: item.fkXqId || undefined,
          campusName: item.xqmc || undefined,
          teachingBuildingId: item.fkJxlId || undefined,
          teachingBuildingName: item.jxlmc || undefined,
        }))
      );
    });
  });
}

/**
 * @Post 请求
 *分页查询
 * @param {data} 参数
 * {floorName} 楼层名称
 * {keyword} 关键字搜索
 * {userId} 当前用户id
 * {teachingBuildingName} 教学楼名称
 * {orgId}  机构id
 * {campusIds} 校区ids 数组
 * 除上面两个参数外 其他参数可自定义
 * @param {config} 配置项
 * @returns
 */
function listPagesFloor(data = PagesData, config = {}) {
  return new Promise((resolve, reject) => {
    request(
      pagingQuery(
        {
          lcmc: data.floorName || undefined, //楼层名称
          orgId: data.orgId || undefined, //机构id
          xqIds:data.campusIds || undefined, //校区ids 数组
          keyword:data.keyword||undefined,//关键字搜索
          userId:data.userId||undefined,//当前用户id
          jxlmc:data.teachingBuildingName||undefined,//教学楼名称
          ...data,
          ...PagesData,
        },
        floorApi.listPagesFloor,
        config
      )
    )
      .then(({ result }) => {
        const { list, pageInfo } = result;
        resolve({
          list:
            list.length > 0
              ? list.map((item) => ({
                  id: item.id || undefined,
                  floorNumber: item.lcbh || undefined,
                  floorName: item.lcmc || undefined,
                  flooMark: item.lcno || undefined,
                  orgId: item.fkJgId || undefined,
                  orgName: item.jgmc || undefined,
                  floorNumber: item.lcbh || undefined,
                  campusId: item.fkXqId || undefined,
                  campusName: item.xqmc || undefined,
                  teachingBuildingId: item.fkJxlId || undefined,
                  teachingBuildingName: item.jxlmc || undefined,
                }))
              : [],
          pageInfo: pageInfo,
        });
      })
      .catch((err) => {
        reject(err);
      });
  });
}

export {
  addFloor,
  updateFloor,
  delBatchFloor,
  getFloorById,
  queryFloorList,
  listPagesFloor,
};
